@@ -755,7 +755,7 @@ EAction.prototype.setCrosshairCursor = function() {
             mask = new QBitmap(EAction.includeBasePath + "/CrosshairCursorMask@2x.png", "PNG");
             //bitmap.setDevicePixelRatio(2);
             //mask.setDevicePixelRatio(2);
-            EAction.crossCursor = new QCursor(bitmap, mask, 15, 15);
+            EAction.crossCursor = new QCursor(bitmap, mask, 30, 30);
         }
         else {
             bitmap = new QBitmap(EAction.includeBasePath + "/CrosshairCursor.png", "PNG");
@@ -2092,7 +2092,7 @@ EAction.getEntityId = function(di, action, event, preview, selectable) {
     }
 
     var altPressed = isAltPressed(event);
-    if (!altPressed || preview || RSettings.getBoolValue("GraphicsView/DisableAltPicking")===true) {
+    if (!altPressed || preview || RSettings.getBoolValue("GraphicsView/DisableAltPicking", false)===true) {
         if (!isNull(action.idFromContextMenu)) {
             // user already chose an entity from the context menu:
             return action.idFromContextMenu;
@@ -2250,3 +2250,7 @@ EAction.warnNotLineArcCircleEllipseSplinePolyline = function() {
 EAction.warnNotPolyline = function() {
     EAction.handleUserWarning(qsTr("Entity is not a polyline."));
 };
+
+EAction.warnNotSplineWithFitPoints = function() {
+    EAction.handleUserWarning(qsTr("Entity is not a spline with fit points."));
+};
